<?php
namespace MascotCoreRofotElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Tribe_Events extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-tribe-events';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Tribe Events', 'mascot-core-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'tm-elementor-widget-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$categories_array = rofot_mascot_category_list_array( 'tribe_events_cat' );
		$orderby_parameters_list1 = mascot_core_rofot_orderby_parameters_list();
		$orderby_parameters_list2 = array(
		);
		$orderby_parameters_list = array_merge( $orderby_parameters_list2, $orderby_parameters_list1 );

		$this->start_controls_section(
				'general',
				[
						'label' => esc_html__( 'General', 'mascot-core-elementor' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
		);
		$this->add_control(
			'custom_css_class', [
				'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'display_type', [
				'label' => esc_html__( "Display Type", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'list-vertical'	=>	esc_html__( 'List - Vertical ', 'mascot-core-elementor' ),
					'list-vertical-slide'	=>	esc_html__( 'List - Vertical Slide', 'mascot-core-elementor' ),
					'grid'	=>	esc_html__( 'Grid', 'mascot-core-elementor' ),
					'masonry'	=>	esc_html__( 'Masonry', 'mascot-core-elementor' ),
					'carousel'	=>	esc_html__( 'Carousel', 'mascot-core-elementor' ),
					'fullwidth'	=>	esc_html__( 'Fullwidth', 'mascot-core-elementor' ),
					'fullwidth-current'	=>	esc_html__( 'Fullwidth - Current Theme', 'mascot-core-elementor' ),
				],
				'default' => 'grid'
			]
		);
		$this->add_control(
			'design_style', [
				'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Style - Default', 'mascot-core-elementor' ),
					'current-theme' => esc_html__( 'Style - Current Theme', 'mascot-core-elementor' ),
				],
				'default' => 'default',
				'condition' => [
					'display_type' => array('grid', 'masonry', 'carousel')
				]
			]
		);
		$this->add_control(
			'columns', [
				'label' => esc_html__( "Columns Layout", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'1'  =>  '1',
					'2'  =>  '2',
					'3'  =>  '3',
					'4'  =>  '4',
					'5'  =>  '5',
					'6'  =>  '6',
				],
				'default' => '3',
				'condition' => [
					'display_type' => array('grid', 'masonry', 'carousel')
				]
			]
		);
		$this->add_control(
			'gutter',
			[
				'label' => esc_html__( "Gutter", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_rofot_isotope_gutter_list_elementor(),
				'default' => 'gutter-15',
				'condition' => [
					'display_type' => array('grid', 'masonry', 'masonry-tiles')
				]
			]
		);

		$this->end_controls_section();


		//List - Vertical Options
		$this->start_controls_section(
			'list_vertical_thumb_options', [
				'label' => esc_html__( 'List Vertical - Thumb Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'display_type' => array('list-vertical', 'list-vertical-slide')
				]
			]
		);
		$this->add_control(
			'vertical_show_left_thumb', [
				'label' => esc_html__( "Show Left Thumbnail Block", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'vertical_left_thumb_image_size', [
				'label' => esc_html__( "Thumb Image Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_rofot_elementor_get_available_image_sizes(),
				'default' => 'rofot_mascot_square_120',
			]
		);
		$this->add_responsive_control(
			'vertical_list_thumb_custom_width',
			[
				'label' => esc_html__( "Custom Thumb Width", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-thumb' => 'width: {{VALUE}};max-width: {{VALUE}};'
				],
			]
		);
		$this->add_responsive_control(
			'vertical_list_thumb_margin',
			[
				'label' => esc_html__( 'Thumb Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-thumb' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'vertical_list_thumb_padding',
			[
				'label' => esc_html__( 'Thumb Padding', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-thumb' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'vertical_list_thumb_border_options',
			[
				'label' => esc_html__( 'Border Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'vertical_list_thumb_border_radius',
			[
				'label' => esc_html__( 'Thumb Border Radius', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-thumb' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'vertical_list_thumb_boxshadow',
				'label' => esc_html__( 'Box Shadow', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-left .event-thumb',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'vertical_list_thumb_border',
				'label' => esc_html__( 'Border', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-left .event-thumb',
			]
		);
		$this->end_controls_section();






		//List - Vertical Options
		$this->start_controls_section(
			'list_vertical_date_options', [
				'label' => esc_html__( 'List Vertical - Date Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'display_type' => array('list-vertical', 'list-vertical-slide')
				]
			]
		);
		$this->add_control(
			'vertical_show_left_date', [
				'label' => esc_html__( "Show Left Date Block", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'vertical_list_left_date_placement', [
				'label' => esc_html__( "Date Block Placement", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'left' => esc_html__( 'Left', 'mascot-core-elementor' ),
					'right' => esc_html__( 'Right', 'mascot-core-elementor' ),
				],
				'default' => 'left',
			]
		);
		$this->add_responsive_control(
			'vertical_list_left_date_custom_width',
			[
				'label' => esc_html__( "Custom Date Block Width", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date' => 'width: {{VALUE}};max-width: {{VALUE}};'
				],
			]
		);
		$this->start_controls_tabs('vertical_list_left_date_typo_tabs');
		$this->start_controls_tab(
			'vertical_list_left_date_day_typo_tab',
			[
				'label' => esc_html__('Day Typography', 'mascot-core-elementor'),
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'left_date_day_typography',
				'label' => esc_html__( 'Day Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-left .event-date .day',
			]
		);
		$this->add_control(
			'left_date_day_text_color',
			[
				'label' => esc_html__( "Day Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date .day' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'left_date_day_text_color_hover',
			[
				'label' => esc_html__( "Day Text Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-left .event-date .day' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'left_date_day_theme_colored',
			[
				'label' => esc_html__( "Day Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date .day' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'left_date_day_theme_colored_hover',
			[
				'label' => esc_html__( "Day Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-left .event-date .day' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_responsive_control(
			'left_date_day_margin',
			[
				'label' => esc_html__( 'Day Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date .day' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'vertical_list_left_date_month_typo_tab',
			[
				'label' => esc_html__('Month Typography', 'mascot-core-elementor'),
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'left_date_month_typography',
				'label' => esc_html__( 'Month Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-left .event-date .month',
			]
		);
		$this->add_control(
			'left_date_month_text_color',
			[
				'label' => esc_html__( "Month Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date .month' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'left_date_month_text_color_hover',
			[
				'label' => esc_html__( "Month Text Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-left .event-date .month' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'left_date_month_theme_colored',
			[
				'label' => esc_html__( "Month Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date .month' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'left_date_month_theme_colored_hover',
			[
				'label' => esc_html__( "Month Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-left .event-date .month' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_responsive_control(
			'left_date_month_margin',
			[
				'label' => esc_html__( 'Month Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date .month' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->start_controls_tabs('vertical_list_left_date_bg_tabs');
		$this->start_controls_tab(
			'vertical_list_left_date_bg_tab',
			[
				'label' => esc_html__('Background Options', 'mascot-core-elementor'),
			]
		);
		$this->add_control(
			'vertical_list_left_date_theme_colored',
			[
				'label' => esc_html__( "Date Block BG Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'vertical_list_left_date_theme_colored_hover',
			[
				'label' => esc_html__( "Date Block BG Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-left .event-date' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'vertical_list_left_date_custom_bg_color',
			[
				'label' => esc_html__( "Date Block BG Custom Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'vertical_list_left_date_custom_bg_color_hover',
			[
				'label' => esc_html__( "Date Block BG Custom Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-left .event-date' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->add_control(
			'vertical_list_left_date_margin_padding_options',
			[
				'label' => esc_html__( 'Margin/Padding Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'vertical_list_left_date_padding',
			[
				'label' => esc_html__( 'Date Block Padding', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'vertical_list_left_date_margin',
			[
				'label' => esc_html__( 'Date Block Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'vertical_list_left_date_border_options',
			[
				'label' => esc_html__( 'Border Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'vertical_list_left_date_border_radius',
			[
				'label' => esc_html__( 'Date Block Border Radius', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-date' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'vertical_list_left_date_boxshadow',
				'label' => esc_html__( 'Date Block Box Shadow', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-left .event-date',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'vertical_list_left_date_border',
				'label' => esc_html__( 'Date Block Border', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-left .event-date',
			]
		);
		$this->end_controls_section();





		//List - Vertical Options
		$this->start_controls_section(
			'list_vertical_options', [
				'label' => esc_html__( 'List - Vertical Wrapper Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'display_type' => array('list-vertical', 'list-vertical-slide')
				]
			]
		);
		$this->start_controls_tabs('tabs_vertical_list_wrapper_styles');
		$this->start_controls_tab(
			'vertical_list_normal',
			[
				'label' => esc_html__('Normal', 'mascot-core-elementor'),
			]
		);
		$this->add_control(
			'vertical_list_vertical_flex_options',
			[
				'label' => esc_html__( 'Vertical Placement Option', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'vertical_list_flex_vertical',
			[
				'label' => esc_html__( "Vertical Alignment", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_rofot_disply_flex_vertical_align_elementor(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event' => 'align-items: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'vertical_list_margin_options',
			[
				'label' => esc_html__( 'Padding/Margin Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'vertical_list_padding',
			[
				'label' => esc_html__( 'List Padding', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'vertical_list_margin',
			[
				'label' => esc_html__( 'List Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'vertical_list_bg_options',
			[
				'label' => esc_html__( 'Background Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'vertical_list_bg_color',
			[
				'label' => esc_html__( "Background Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event' => 'background-color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'vertical_list_bg_theme_colored',
			[
				'label' => esc_html__( "Background Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'vertical_list_border_radius',
			[
				'label' => esc_html__( 'Thumb Border Radius', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-left .event-thumb' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'vertical_list_boxshadow',
				'label' => esc_html__( 'Box Shadow', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'vertical_list_border',
				'label' => esc_html__( 'Border', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event',
			]
		);
		$this->end_controls_tab();



		$this->start_controls_tab(
			'vertical_list_hover',
			[
				'label' => esc_html__('Hover', 'mascot-core-elementor'),
			]
		);
		$this->add_control(
			'vertical_list_hover_bg_options',
			[
				'label' => esc_html__( 'Background Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'vertical_list_hover_bg_color',
			[
				'label' => esc_html__( "Background Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover' => 'background-color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'vertical_list_hover_bg_theme_colored',
			[
				'label' => esc_html__( "Background Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'vertical_list_hover_boxshadow',
				'label' => esc_html__( 'Box Shadow', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event:hover',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'vertical_list_hover_border',
				'label' => esc_html__( 'Border', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event:hover',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'vertical_last_item_list_last_item',
			[
				'label' => esc_html__('Last Item', 'mascot-core-elementor'),
			]
		);
		$this->add_responsive_control(
			'vertical_list_last_item_padding',
			[
				'label' => esc_html__( 'Last Item Padding', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event:last-child' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'vertical_list_last_item_margin',
			[
				'label' => esc_html__( 'Last Item Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event:last-child' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'vertical_list_last_item_border',
				'label' => esc_html__( 'Last Item Border', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event:last-child',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();



		//List - Vertical Slide Options
		$this->start_controls_section(
			'list_vertical_slide_options', [
				'label' => esc_html__( 'List - Vertical Slide Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'display_type' => array('list-vertical-slide')
				]
			]
		);
		$this->add_control(
			'vertical_slide_minslides', [
				'label' => esc_html__( "Number of Minimum Sliding Items", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '3'
			]
		);
		$this->add_control(
			'vertical_slide_autoplay', [
				'label' => esc_html__( "Autoplay", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'vertical_slide_show_navigation', [
				'label' => esc_html__( "Show Navigation Arrow", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'vertical_slide_navigation_arrow_position', [
				'label' => esc_html__( "Navigation Arrow Position", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'bottom'	=>	esc_html__( 'Bottom', 'mascot-core-elementor' ),
					'top'	=>	esc_html__( 'Top', 'mascot-core-elementor' )
				],
				'default' => 'top',
				'condition' => [
					'vertical_slide_show_navigation' => array('yes')
				]
			]
		);
		$this->end_controls_section();








		//Carousel Options
		$this->start_controls_section(
			'carousel_options', [
				'label' => esc_html__( 'Carousel Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'display_type' => array('carousel')
				]
			]
		);
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 1, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 2, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 3, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 4, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 5, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 6, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 7, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 8, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 9, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 10, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 11, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 12, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 13, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_arraylist( $this, 14, '', array('display_type' => array('carousel') ) );
		$this->end_controls_section();

		//Carousel Arrow Navigation Options
		$this->start_controls_section(
			'carousel_arrow_nav_options', [
				'label' => esc_html__( 'Carousel Arrow Navigation Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 1, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 2, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 3, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 4, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 5, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 6, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 7, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 8, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 9, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 10, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 11, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 12, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 13, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 14, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 15, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 16, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 17, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 18, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 19, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 20, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 21, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 22, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 23, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 24, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 25, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 26, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 27, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 28, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_arraylist( $this, 29, '');
		$this->end_controls_section();




		

		//Carousel Arrow Navigation Options
		$this->start_controls_section(
			'carousel_arrow_nav_bs5_breakpoints_options', [
				'label' => esc_html__( 'Carousel Arrow Nav Bootstrap5 Breakpoints', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 1, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 2, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 3, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 4, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 5, '');

		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 6, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 7, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 8, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 9, '');
		mascot_core_rofot_elementor_get_owl_carousel_nav_bs5_breakpoints_arraylist( $this, 10, '');
		$this->end_controls_section();






		//Carousel Bullets/Dots Options
		$this->start_controls_section(
			'carousel_arrow_dots_options', [
				'label' => esc_html__( 'Carousel Bullets/Dots Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 1, '', array('display_type' => array('carousel') ) );
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 2, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 3, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 4, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 5, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 6, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 7, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 8, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 9, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 10, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 11, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 12, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 13, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 14, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 15, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 16, '');
		mascot_core_rofot_elementor_get_owl_carousel_dots_arraylist( $this, 17, '');
		$this->end_controls_section();




		$this->start_controls_section(
			'query', [
				'label' => esc_html__( 'Query', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'total_items', [
				'label' => esc_html__( "Number of Items to Query from Database", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				"description" => esc_html__( "How many items do you wish to show? Put -1 to show all. Default 3", 'mascot-core-elementor' ),
				'default' => '3'
			]
		);
		$this->add_control(
			'category', [
				'label' => esc_html__( "Category", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => $categories_array,
			]
		);
		$this->add_control(
			'order_by', [
				'label' => esc_html__( "Order By", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => $orderby_parameters_list,
			]
		);
		$this->add_control(
			'order', [
				'label' => esc_html__( "Order", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'DESC' => esc_html__( 'Descending', 'mascot-core-elementor' ),
					'ASC' => esc_html__( 'Ascending', 'mascot-core-elementor' ),
				],
			]
		);

		$this->end_controls_section();




		//Category Filter
		$this->start_controls_section(
			'cat_filter_section', [
				'label' => esc_html__( 'Category Filter', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		mascot_core_rofot_elementor_get_cat_filter_arraylist( $this, 1, array('display_type' => array('grid', 'masonry', 'carousel') ) );
		mascot_core_rofot_elementor_get_cat_filter_arraylist( $this, 2 );
		mascot_core_rofot_elementor_get_cat_filter_arraylist( $this, 3 );
		mascot_core_rofot_elementor_get_cat_filter_arraylist( $this, 4 );

		$this->end_controls_section();







		//Content Options
		$this->start_controls_section(
			'title_styling_options',
			[
				'label' => esc_html__( 'Title Styling', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Title Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-content .event-title,{{WRAPPER}} .event .event-content .event-title a',
			]
		);
		$this->add_control(
			'title_text_color',
			[
				'label' => esc_html__( "Title Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .event .event-content .event-title a' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'title_text_color_wrapper_hover',
			[
				'label' => esc_html__( "Title Text Color (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .event:hover .event-content .event-title a' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'title_text_color_hover',
			[
				'label' => esc_html__( "Title Text Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-title:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .event .event-content .event-title a:hover' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'title_theme_colored',
			[
				'label' => esc_html__( "Title Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-title' => 'color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .event .event-content .event-title a' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'title_theme_colored_wrapper_hover',
			[
				'label' => esc_html__( "Title Theme Colored (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-title' => 'color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .event:hover .event-content .event-title a' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'title_theme_colored_hover',
			[
				'label' => esc_html__( "Title Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-title:hover' => 'color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .event .event-content .event-title a:hover' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'title_margin',
			[
				'label' => esc_html__( 'Title Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();







		$this->start_controls_section(
			'date_single_meta_styling_options',
			[
				'label' => esc_html__( 'Single Date Meta Styling', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'date_single_meta_typography',
				'label' => esc_html__( 'Date Meta Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-content .event-single-meta-date',
			]
		);
		$this->add_responsive_control(
			'date_single_meta_padding',
			[
				'label' => esc_html__( 'Date Meta Padding', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'date_single_meta_margin',
			[
				'label' => esc_html__( 'Date Meta Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'date_single_meta_text_color_options',
			[
				'label' => esc_html__( 'Text Color Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'date_single_meta_text_color',
			[
				'label' => esc_html__( "Date Meta Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'date_single_meta_text_color_wrapper_hover',
			[
				'label' => esc_html__( "Date Meta Text Color (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-single-meta-date' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'date_single_meta_text_color_hover',
			[
				'label' => esc_html__( "Date Meta Text Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date:hover' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'date_single_meta_theme_colored',
			[
				'label' => esc_html__( "Date Meta Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'date_single_meta_theme_colored_wrapper_hover',
			[
				'label' => esc_html__( "Date Meta Theme Colored (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-single-meta-date' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'date_single_meta_theme_colored_hover',
			[
				'label' => esc_html__( "Date Meta Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date:hover' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'date_single_meta_bg_color_options',
			[
				'label' => esc_html__( 'Background Color Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'date_single_meta_bg_color',
			[
				'label' => esc_html__( "Date Meta BG Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'date_single_meta_bg_color_wrapper_hover',
			[
				'label' => esc_html__( "Meta BG Color (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-single-meta-date' => 'background-color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'date_single_meta_bg_color_hover',
			[
				'label' => esc_html__( "Date Meta BG Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date:hover' => 'background-color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'date_single_meta_bg_theme_colored',
			[
				'label' => esc_html__( "Date Meta BG Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'date_single_meta_bg_theme_colored_wrapper_hover',
			[
				'label' => esc_html__( "Date Meta BG Theme Colored (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-single-meta-date' => 'background-color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'date_single_meta_bg_theme_colored_hover',
			[
				'label' => esc_html__( "Meta BG Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-single-meta-date:hover' => 'background-color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->end_controls_section();




		$this->start_controls_section(
			'meta_styling_options',
			[
				'label' => esc_html__( 'Post Meta Styling', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'post_meta_placement', [
				'label' => esc_html__( "Post Meta Placement", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'top' => esc_html__( 'Over Title', 'mascot-core-elementor' ),
					'center' => esc_html__( 'Under Title', 'mascot-core-elementor' ),
					'bottom' => esc_html__( 'Under Excerpt', 'mascot-core-elementor' ),
				],
				'default' => 'center',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typography',
				'label' => esc_html__( 'Post Meta Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-content .event-meta, {{WRAPPER}} .event .event-content .event-meta a',
			]
		);
		$this->add_control(
			'meta_text_color',
			[
				'label' => esc_html__( "Meta Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta, {{WRAPPER}} .event .event-content .event-meta a' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'meta_text_color_wrapper_hover',
			[
				'label' => esc_html__( "Meta Text Color (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-meta' => 'color: {{VALUE}};',
					'{{WRAPPER}} .event:hover .event-content .event-meta a' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'meta_text_color_hover',
			[
				'label' => esc_html__( "Meta Text Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .event .event-content .event-meta a:hover' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'meta_theme_colored',
			[
				'label' => esc_html__( "Meta Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta, {{WRAPPER}} .event .event-content .event-meta a' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'meta_theme_colored_wrapper_hover',
			[
				'label' => esc_html__( "Meta Theme Colored (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-meta' => 'color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .event:hover .event-content .event-meta a' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'meta_theme_colored_hover',
			[
				'label' => esc_html__( "Meta Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta:hover' => 'color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .event .event-content .event-meta a:hover' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_responsive_control(
			'meta_margin',
			[
				'label' => esc_html__( 'Post Meta Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta, {{WRAPPER}} .event .event-content .event-meta a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'meta_icon_options',
			[
				'label' => esc_html__( 'Post Meta Icon Options', 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'meta_icon_typography',
				'label' => esc_html__( 'Post Meta Icon Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-content .event-meta i, {{WRAPPER}} .event .event-content .event-meta a i',
			]
		);
		$this->add_control(
			'meta_icon_text_color',
			[
				'label' => esc_html__( "Meta Icon Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta i, {{WRAPPER}} .event .event-content .event-meta a i' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'meta_icon_text_color_wrapper_hover',
			[
				'label' => esc_html__( "Meta Icon Text Color (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-meta i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .event:hover .event-content .event-meta a i' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'meta_icon_theme_colored',
			[
				'label' => esc_html__( "Meta Icon Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-meta i, {{WRAPPER}} .event .event-content .event-meta a i' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'meta_icon_theme_colored_wrapper_hover',
			[
				'label' => esc_html__( "Meta Icon Theme Colored (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-meta i' => 'color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .event:hover .event-content .event-meta a i' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->end_controls_section();





		$this->start_controls_section(
			'excerpt_styling_options',
			[
				'label' => esc_html__( 'Excerpt Styling', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'excerpt_typography',
				'label' => esc_html__( 'Excerpt Typography', 'mascot-core-elementor' ),
				'selector' => '{{WRAPPER}} .event .event-content .event-excerpt',
			]
		);
		$this->add_control(
			'excerpt_text_color',
			[
				'label' => esc_html__( "Excerpt Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-excerpt' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'excerpt_text_color_wrapper_hover',
			[
				'label' => esc_html__( "Excerpt Text Color (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-excerpt' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'excerpt_text_color_hover',
			[
				'label' => esc_html__( "Excerpt Text Color (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-excerpt:hover' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_control(
			'excerpt_theme_colored',
			[
				'label' => esc_html__( "Excerpt Theme Colored", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-excerpt' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'excerpt_theme_colored_wrapper_hover',
			[
				'label' => esc_html__( "Excerpt Theme Colored (Wrapper Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event:hover .event-content .event-excerpt' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'excerpt_theme_colored_hover',
			[
				'label' => esc_html__( "Excerpt Theme Colored (Hover)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => rofot_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-excerpt:hover' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_responsive_control(
			'excerpt_margin',
			[
				'label' => esc_html__( 'Excerpt Margin', 'mascot-core-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .event .event-content .event-excerpt, {{WRAPPER}} .event .event-content .event-excerpt a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();




		//Content Options
		$this->start_controls_section(
			'content',
			[
				'label' => esc_html__( 'Contents Show/Hide', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'show_thumb', [
				'label' => esc_html__( "Show Thumbnail", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'feature_thumb_image_size', [
				'label' => esc_html__( "Thumbnail Image Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_rofot_elementor_get_available_image_sizes(),
				'default' => 'post-thumbnail',
				'condition' => [
					'show_thumb' => array('yes'),
				]
			]
		);
		$this->add_control(
			'show_title',
			[
				'label' => esc_html__( "Show Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'title_tag',
			[
				'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_rofot_heading_tag_list(),
				'default' => 'h5',
				'condition' => [
					'show_title' => array('yes')
				]
			]
		);
		$this->add_control(
			'show_excerpt',
			[
				'label' => esc_html__( "Show Excerpt", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'excerpt_length', [
				'label' => esc_html__( "Excerpt Length", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				"description" => esc_html__( "Number of words to display. Example: 25. Default all", 'mascot-core-elementor' ),
				'condition' => [
					'show_excerpt' => array('yes')
				]
			]
		);
		$this->add_control(
			'show_meta',
			[
				'label' => esc_html__( "Show Post Meta", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'meta_options',
			[
				'label' => esc_html__( "Choose Meta", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => [
					'show-date-over-image'	=>	esc_html__( 'Show Date Over Image', 'mascot-core-elementor' ),
					'show-full-date'	=>	esc_html__( 'Show Full Date & Time', 'mascot-core-elementor' ),
					'show-time'	=>	esc_html__( 'Show Only Time', 'mascot-core-elementor' ),
					'show-venue'	=>	esc_html__( 'Show Venue', 'mascot-core-elementor' ),
					'show-organizer'	=>	esc_html__( 'Show Organizer', 'mascot-core-elementor' ),
				],
				'multiple' => true,
				'description' => esc_html__('Enable/Disabling this option will show/hide each Post Meta', 'mascot-core-elementor'),
				'default' => [ 'show-date-over-image', 'show-time' ],
				'condition' => [
					'show_meta' => array('yes')
				]
			]
		);
		$this->add_control(
			'show_single_date_meta',
			[
				'label' => esc_html__( "Show Single Date Meta", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'show_single_date_meta_options',
			[
				'label' => esc_html__( "Choose Meta", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => [
					'show-date'	=>	esc_html__( 'Show Only Date', 'mascot-core-elementor' ),
					'show-time'	=>	esc_html__( 'Show Only Time', 'mascot-core-elementor' ),
					'show-full-date'	=>	esc_html__( 'Show Full Date & Time', 'mascot-core-elementor' ),
				],
				'default' => 'show-date',
				'condition' => [
					'show_single_date_meta' => array('yes')
				]
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'button_options', [
					'label' => esc_html__( 'Button Options', 'mascot-core-elementor' ),
					'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		mascot_core_rofot_elementor_get_viewdetails_button_arraylist($this, 1);
		mascot_core_rofot_elementor_get_viewdetails_button_arraylist($this, 2);
		mascot_core_rofot_elementor_get_button_arraylist($this, 1);
		mascot_core_rofot_elementor_get_button_arraylist($this, 2);
		mascot_core_rofot_elementor_get_button_arraylist($this, 3);
		mascot_core_rofot_elementor_get_button_arraylist($this, 4);
		mascot_core_rofot_elementor_get_button_arraylist($this, 5);
		mascot_core_rofot_elementor_get_button_arraylist($this, 6);
		mascot_core_rofot_elementor_get_button_arraylist($this, 7);
		mascot_core_rofot_elementor_get_button_arraylist($this, 8);
		mascot_core_rofot_elementor_get_button_arraylist($this, 9);
		mascot_core_rofot_elementor_get_button_arraylist($this, 10);
		mascot_core_rofot_elementor_get_button_arraylist($this, 11);
		mascot_core_rofot_elementor_get_button_arraylist($this, 12);

		$this->end_controls_section();






		$this->start_controls_section(
			'loadmore_button_options', [
					'label' => esc_html__( 'Loadmore Button Options', 'mascot-core-elementor' ),
					'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		mascot_core_rofot_elementor_get_viewdetails_button_arraylist($this, 1,  esc_html__( "Load More", 'mascot-core-elementor' ), 'loadmore_');
		mascot_core_rofot_elementor_get_viewdetails_button_arraylist($this, 2,  esc_html__( "Load More", 'mascot-core-elementor' ), 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 1, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 2, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 3, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 4, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 5, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 6, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 7, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 8, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 9, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 10, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 11, 'loadmore_');
		mascot_core_rofot_elementor_get_button_arraylist($this, 12, 'loadmore_');

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$class_instance =  '';

		$settings['holder_id'] = rofot_mascot_get_isotope_holder_ID('events');

		if (  $settings['loadmore_show_view_details_button'] === 'yes' ) {
			$holder_id = str_replace('-', '_', $settings['holder_id']);
			$settings['holder_id_underline'] = $holder_id;
			$settings['wp_ajax_load_for_cpt'] = 'tribe_events';

			wp_localize_script( 'rofot-custom', 'tm_loadmore_params_'.$holder_id, array(
				'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php',

				'class_instance' => $class_instance,
				'params' => $settings,

				'current_page' => get_query_var( 'paged' ) ? get_query_var('paged') : 1,
			) );
			wp_enqueue_script( 'rofot-custom' );
		}


		return mascot_core_rofot_elementor_sc_tribe_events_render_output( $class_instance, $settings );

	}
}



if(!function_exists('mascot_core_rofot_elementor_sc_tribe_events_render_output')) {
	/**
	 * Output render
	 */
	function mascot_core_rofot_elementor_sc_tribe_events_render_output( $class_instance, $settings ) {
		$new_cpt_class = $class_instance;
		$paged = isset($settings['paged']) ? $settings['paged'] : '';

		//query args
		$args = array(
			'post_type' => 'tribe_events',
			'orderby' => $settings['order_by'],
			'order' => $settings['order'],
			'posts_per_page' => $settings['total_items'],
			'paged' => $paged,
		);

		//if category selected
		if( ! empty( $settings['category'] ) ) {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'tribe_events_cat',
					'field'	=> 'slug',
					'terms'	=> explode(',', $settings['category']),
				)
			);
		}

		$the_query = new \WP_Query( $args );
		$settings['the_query'] = $the_query;
		
		if ( !$the_query->have_posts() && isset( $settings['from_loadmore_ajax_handler'] ) && $settings['from_loadmore_ajax_handler'] === true ) {
			return;
		}


		//classes
		$classes = array();
		if( $settings['display_type'] == 'list-vertical-slide' && $settings['vertical_slide_show_navigation'] != 'false' ) {
			$classes[] = 'has-nav-arrow nav-arrow-position-' . $settings['vertical_slide_navigation_arrow_position'];
		}
		$classes[] = $settings['custom_css_class'];
		$settings['classes'] = $classes;

		//button classes
		$settings['btn_classes'] = rofot_mascot_prepare_button_classes_from_params( $settings );
		$settings['loadmore_btn_classes'] = rofot_mascot_prepare_button_classes_from_params( $settings, 'loadmore_' );


		//event-date classes
		$event_left_classes = array();
		$settings['event_left_classes'] = $event_left_classes;
		
		//Owl Carousel Data
		$settings['owl_carousel_data_info'] = rofot_mascot_prepare_owlcarousel_data_from_params( $settings );

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_rofot_elementor_get_shortcode_template_part( 'tribe-events', $settings['display_type'], 'tribe-events/tpl', $settings, true );
		
		echo $html;
	}
}